;;====================================================================
;; File			: logon.asm
;; Author		: Deva
;; Created	: 2012-01-11
;; Version	: 1.0
;; Summery	: Boot/Initial system,ap logon
;; History	: 
;;
;;====================================================================
	PW	132		; .LST's page width	= 128 characters.
	CHIP W65C02S		; Define chip :	ST2024C	base on	65c02.
;	GLOBALS	ON		; Global all labels
	LIST ON			; List sources
	CASE ON			; Care Upper-case	or lower-case.
	SPACES ON		; Make all labels public.
	EXTERNS ON
;;====================================================================
	.include common.inc
	.include config.inc
	.include lcd.inc
	.include key.inc
	
;;====================================================================
IVT				.SECTION
;;====================================================================
		.WORD	IF_Rtc							;14;4;FFE0
		.WORD	IF_Brk							;BREAK VECTOR. (SAME 6502)
		.WORD	IF_Brk							;BREAK VECTOR. (SAME 6502)
		.WORD	IF_Usb							;14;4;FFE0
		.WORD	IF_Brk							;BREAK VECTOR. (SAME 6502)
		.WORD	IF_Brk							;BREAK VECTOR. (SAME 6502)
		.WORD	IF_Srx							;11;4;FFE6
		.WORD	IF_Stx							;10;4;FFE8
		.WORD	IF_Lcdfr						;06;6;FFEC LCD Frame interupt
		.WORD	IF_BaseTimer				;BASE TIMER	OVERFLOW.
		.WORD	IF_Port							;PORTA[7-0]	VECTOR.
		.WORD	IF_Timer3						;BREAK VECTOR. (SAME 6502)
		.WORD	IF_Timer2						;TIMER 2 OVERFLOW.
		.WORD	IF_Timer1						;TIMER 1 OVERFLOW.
		.WORD	IF_Timer0						;TIMER 0 OVERFLOW.
		.WORD	IF_Intx							;PORTA[0]/INTX VECTOR.
		.WORD	IF_Nmi							;NMI VECTOR. (RESERVED)
		.WORD	IF_Reset						;RESET VECTOR. (SAME 6502)
		.WORD	IF_Brk							;BREAK VECTOR. (SAME 6502)
;;====================================================================
					.ENDS
;;====================================================================

;;====================================================================
UBOOT			.SECTION
;;====================================================================
.ifdef _USB_BOOT
	.DB 000H,055H,0AAH,0FFH
	.DB 0FFH,0AAH,055H,000H
;	.DB 0FFH,0FFH,0FFH,0FFH
;	.DB 0FFH,0FFH,0FFH,0FFH
.else
	.STRING "First Version",00H,FFH,FFH
.endif

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
IF_Reset:
	SEI
	LDX #STACK_TOP
	TXS
	CLD
	STZ <IENAL
	STZ <IREQL
	STZ <IREQL
	STZ <IREQH
	STZ <MISC	;RESET WDT
	STZ <USBCON
	STZ <USBIEN
	
	JSR F_ClearRam	
	jsr F_InitPort
	JSR F_InitBus	
	JSR F_InitSysclk
	JSR F_InitPsg

	JSR F_InitIntSrv
;	JSR F_InitLCD	
	JSR F_LoadProgramToRam01
	JSR F_LoadProgramToRam01_IRR
	;MOV #00FH,<PDAC
	;BRA $
;	JSR F_InitLCD
	__InitLCD
	__InitKey
	;__SetMadCtl #ROTATE_MIR_270   ;x/y ת
	__SetMadCtl #ROTATE_270
	JSR F_StartIntSrv
	LJSR __main_
	WAI

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
F_ClearRam:
	LDX	#$80
?_LOOP_1:
	STZ	<$00,X
	INX
	BNE	?_LOOP_1
?_LOOP_2:
	STZ	$200,X
	STZ	$300,X
	STZ	$400,X
	STZ	$500,X
	STZ	$600,X
	STZ	$700,X
	INX
	BNE	?_LOOP_2
	RTS

;;==============================================
F_L_Jsr00:
		STA		<R_A_Reg				;A's temporary register
		LDA		<PRRH					;Get original program bank
		PHA							;Push original bank	register
		LDA		<PRRL					;Get original program bank
		PHA							;Push original bank	register
		JSR		R_JSR_BUFFER+0FH					;JMP L_Rts00 + ѹվ
		STA		<R_A_Reg
		BRA		F_L_Rts00_Out
L_Rts00:
		STY		<R_Y_Reg				;Save Y	register
		PHX								;Save X	register
		TSX								;Stack pointer -> X
		CLC
		LDA		R_JSR_BUFFER+6,X				;Get address(low order)
		STA		<R_L_J_Inx				;set index(low order)
		ADC		#4
		STA		R_JSR_BUFFER+6,X				;Offset	return address
		LDA		R_JSR_BUFFER+7,X				;Get address(high order)
		STA		<R_L_J_Inx+1			;Set index(high	order)
		ADC		#0
		STA		R_JSR_BUFFER+7,X
		PLX								;Restore X register
		LDY		#4
?_L_L_Jsr00_0:
		LDA		(R_L_J_Inx),Y
		PHA
		DEY
		BNE		?_L_L_Jsr00_0
		LDY		<R_Y_Reg
F_L_Rts00_Out:
		PLA
		STA		<PRRL
		PLA
		STA		<PRRH
		LDA		<R_A_Reg
		RTS
;;==============================================
F_L_Jsr00_IRR:
		STA		<I_A_Reg				;A's temporary register
		LDA		<IRRH					;Get original program bank
		PHA							;Push original bank	register
		LDA		<IRRL					;Get original program bank
		PHA							;Push original bank	register
		JSR		I_JSR_BUFFER+0FH			;JMP L_Rts00_IRR + ѹվ
		STA		<I_A_Reg
		BRA		F_L_Rts00_IRR_Out
L_Rts00_IRR:
		STY		<I_Y_Reg				;Save Y	register
		PHX							;Save X	register
		TSX							;Stack pointer -> X
		CLC
		LDA		R_JSR_BUFFER+6,X			;Get address(low order)
		STA		<I_L_J_Inx				;set index(low order)
		ADC		#4
		STA		R_JSR_BUFFER+6,X			;Offset	return address
		LDA		R_JSR_BUFFER+7,X			;Get address(high order)
		STA		<I_L_J_Inx+1				;Set index(high	order)
		ADC		#0
		STA		R_JSR_BUFFER+7,X			;Return	address	+3
		PLX							;Restore X register
		LDY		#4
?_L_L_Jsr00_IRR_0:
		LDA		(I_L_J_Inx),Y
		PHA
		DEY
		BNE		?_L_L_Jsr00_IRR_0
		LDY		<I_Y_Reg
F_L_Rts00_IRR_Out:
		PLA
		STA		<IRRL
		PLA
		STA		<IRRH
		LDA		<I_A_Reg
		RTS
;;==============================================
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
F_LoadProgramToRam01:
.ifndef	_USB_BOOT
	STZ		<DCTR
	STZ		<DMOD
	LDA		#<F_L_Jsr00+4000H
	STA		<DPTRL
	LDA		#>F_L_Jsr00+4000H
	STA		<DPTRH
	LDA		#<C_NorFlash_CS_Drr
	STA		<DBKRL
	LDA		#>C_NorFlash_CS_Drr
	STA		<DBKRH
	LDA		#01H
	STA		<DCTR
	LDA		#<8000H
	STA		<DBKRL
	LDA		#>8000H
	STA		<DBKRH
	LDA		#<R_JSR_BUFFER
	STA		<DPTRL
	LDA		#>R_JSR_BUFFER
	STA		<DPTRH
	LDA		#<03CH-1
	STA		<DCNTL
	LDA		#>03CH-1
	STA		<DCNTH
.else
	LDA		#<C_NorFlash_CS_Drr
	STA		<DRRL
	LDA		#>C_NorFlash_CS_Drr
	STA		<DRRH
	LDX		#03CH-1
L_LoopMove:
	LDA		F_L_Jsr00+4000H,X
	STA		R_JSR_BUFFER,X
	DEX
	CPX		#0FFH
	BNE		L_LoopMove
.endif
;;==============================================
; This program must used interrupt program subroutine
;;==============================================
F_LoadProgramToRam01_IRR:
.ifndef _USB_BOOT
	BBR1	<SYS,L_LoadProgramToRam_IRR_End01
	STZ		<DCTR
	STZ		<DMOD
	LDA		#<F_L_Jsr00_IRR+4000H
	STA		<DPTRL
	LDA		#>F_L_Jsr00_IRR+4000H
	STA		<DPTRH
	LDA		#<C_NorFlash_CS_Drr
	STA		<DBKRL
	LDA		#>C_NorFlash_CS_Drr
	STA		<DBKRH
	LDA		#01H
	STA		<DCTR
	LDA		#<8000H
	STA		<DBKRL
	LDA		#>8000H
	STA		<DBKRH
	LDA		#<I_JSR_BUFFER
	STA		<DPTRL
	LDA		#>I_JSR_BUFFER
	STA		<DPTRH
	LDA		#<03CH-1
	STA		<DCNTL
	LDA		#>03CH-1
	STA		<DCNTH
.else
	LDA		#<C_NorFlash_CS_Drr
	STA		<DRRL
	LDA		#>C_NorFlash_CS_Drr
	STA		<DRRH
	LDX		#03CH-1
L_LoopMove_IRR:
	LDA		F_L_Jsr00_IRR+4000H,X
	STA		I_JSR_BUFFER,X
	DEX
	CPX		#0FFH
	BNE		L_LoopMove_IRR
.endif
L_LoadProgramToRam_IRR_End01:
	RTS
	
T_Table:
	.DB 000H,055H,0AAH,0FFH
	.DB 0FFH,0AAH,055H,000H
	.DB 0FFH,0FFH,0FFH,0FFH
	.DB 0FFH,0FFH,0FFH,0FFH
;;====================================================================
					.ENDS
;;====================================================================
